from distutils.core import setup
setup(
    name = 'json_dict_comparator',
    packages = ['json_dict_comparator'],
    version = '0.0.3',
    license='MIT',
    description = 'Provides tools for comparing python dictionaries obtained from json objects.',
    author = 'Humberto Cezar',
    author_email = 'betoncios@gmail.com',
    url = 'https://github.com/humbcezar/json-dict-comparator',
    download_url = 'https://github.com/humbcezar/json-dict-comparator/archive/0.0.3.tar.gz',
    keywords = ['json', 'dict', 'comparison'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.8',
    ],
)
